@@ -50,6 +50,7 @@ class BaseDriver(object):
         self._api_suffix = '/api/json?method='
         self._url = url
         self._debug = False
+        self.auth = None
 
     @property
     def url(self):
@@ -58,7 +59,7 @@ class BaseDriver(object):
         return self._url
 
     @url.setter
-    def url_set(self, value):
+    def url(self, value):
         """Set the url
         """
         self._url = value
@@ -101,12 +102,14 @@ class BaseDriver(object):
                                data=file_payload.read(),
                                params=parameters,
                                allow_redirects=True,
-                               verify=False)
+                               verify=False,
+                               auth=self.auth)
         else:
             request = http.post(method_url,
                                 params=parameters,
                                 allow_redirects=True,
-                                verify=False)
+                                verify=False,
+                                auth=self.auth)
         code = request.status_code
         if self._debug:
             print request.content
@@ -115,7 +118,7 @@ class BaseDriver(object):
                                  "%d" % code)
         try:
             response = json.loads(request.content)
-        except json.JSONDecodeError:
+        except ValueError:
             raise PydasException("Request failed with HTTP error code "
                                  "%d and request.content %s" % (code, request.content))
 
@@ -365,7 +368,6 @@ class CoreDriver(BaseDriver):
         parameters['token'] = token
         parameters['name'] = name
         parameters['parentid'] = parentid
-        parameters['privacy'] = 'Public'
         optional_keys = ['description', 'uuid', 'privacy']
         for key in optional_keys:
             if key in kwargs:
